@@ -5,11 +5,17 @@
 // released under the GNU GPL 3 or later
 // see file COPYING or www.gnu.org for details
 
-
-#include "../../libweed/weed.h"
-#include "../../libweed/weed-palettes.h"
-#include "../../libweed/weed-effects.h"
-#include "../../libweed/weed-plugin.h"
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-palettes.h"
+#include "weed/weed-effects.h"
+#include "weed/weed-plugin.h"
+#else
+#include "../../../libweed/weed.h"
+#include "../../../libweed/weed-palettes.h"
+#include "../../../libweed/weed-effects.h"
+#include "../../../libweed/weed-plugin.h"
+#endif
 
 ///////////////////////////////////////////////////////////////////
 
@@ -20,8 +26,13 @@ static int package_version=2; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
-#include "../../libweed/weed-utils.h" // optional
-#include "../../libweed/weed-plugin-utils.h" // optional
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed-utils.h" // optional
+#include "weed/weed-plugin-utils.h" // optional
+#else
+#include "../../../libweed/weed-utils.h" // optional
+#include "../../../libweed/weed-plugin-utils.h" // optional
+#endif
 
 /////////////////////////////////////////////////////////////
 
@@ -336,18 +347,11 @@ static void setxypos(double dwidth, double dheight, double x, double y, int *x_t
 }
 
 
-static void rotate_text(cairo_t *cairo, PangoLayout *layout, int x_center, int y_center, double radians) {
-  cairo_translate (cairo, x_center, y_center);
-  cairo_rotate (cairo, radians);
-  
-  /* Inform Pango to re-layout the text with the new transformation */
-  pango_cairo_update_layout (cairo, layout);
-}
 
 
-    // set font size
-void set_font_size(PangoLayout *layout, PangoFontDescription *font, int font_size) {
-  pango_font_description_set_absolute_size(font, font_size*PANGO_SCALE);
+// set font size
+static void set_font_size(PangoLayout *layout, PangoFontDescription *font, int font_size) {
+  pango_font_description_set_size(font, font_size*PANGO_SCALE);
   pango_layout_set_font_description(layout, font);
 }
 
@@ -394,6 +398,14 @@ static void letter_data_free(sdata_t *sdata) {
   sdata->letter_data=NULL;
 }
 
+static void rotate_text(cairo_t *cairo, PangoLayout *layout, int x_center, int y_center, double radians) {
+ cairo_translate (cairo, x_center, y_center);
+ cairo_rotate (cairo, radians);
+
+ /* Inform Pango to re-layout the text with the new transformation */
+ pango_cairo_update_layout (cairo, layout);
+}
+
 
 static void proctext(sdata_t *sdata, weed_timecode_t tc, char *xtext, cairo_t *cairo, PangoLayout *layout, 
 		     PangoFontDescription *font, int width, int height) {
@@ -952,7 +964,7 @@ int puretext_process (weed_plant_t *inst, weed_timecode_t tc) {
 	result = pl_pixbuf_to_channel(out_channel, pixbuf_new);
 	g_object_unref(pixbuf_new);
       }
-      cairo_destroy(cairo);
+
     }
     g_object_unref(pixmap);
   }
