@@ -7,9 +7,15 @@
 // dynamic window generation from parameter arrays :-)
 // special widgets
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-palettes.h"
+#include "weed/weed-host.h"
+#else
 #include "../libweed/weed.h"
 #include "../libweed/weed-palettes.h"
 #include "../libweed/weed-host.h"
+#endif
 
 #include "main.h"
 #include "resample.h"
